#!/usr/bin/perl

use Data::Dumper;

if (scalar(@ARGV) < 4)
{
	die("Usage: $0 filename_start_frame_column filename_delimiter time_slot_length mesh_filename");
}

$filename_start_frame_column = $ARGV[0];
$filename_delimiter = $ARGV[1];
$time_slot_length = $ARGV[2];
$mesh_filename = $ARGV[3];

open(MESH, $mesh_filename) or die("Can not open file '$mesh_filename'\n");
$mesh_filename =~ s/^.*\///;
@a = split(/$filename_delimiter/, $mesh_filename);
$segment_start_time = $a[$filename_start_frame_column-1] / 100;
#print "start_time:$segment_start_time\n";

@aligns = ();

while(<MESH>)
{
	chomp;
#	print "line: $_\n";

	if ($_ =~ /^align/)
	{
		@a = split(/\s+/, $_);
		shift(@a);
		$align_id = shift(@a);
#		print "align_id=$align_id\n";
		while (scalar(@a) > 0)
		{
			$w = shift(@a);
			$p = shift(@a);
			$aligns[$align_id]{$w}{'p'} = $p;
			$aligns[$align_id]{$w}{'start'} = $segment_start_time;
		}
	}
	elsif ($_ =~ /^info/)
	{
		@a = split(/\s+/, $_);
		shift(@a);
		$align_id = shift(@a);
		$w        = shift(@a);
		$aligns[$align_id]{$w}{'start'} = shift(@a) + $segment_start_time;
		$aligns[$align_id]{$w}{'dur'}   = shift(@a) - 0.01; # make it 1 frame less otherwise it causes problems (segments overlap)
	}
}

@time_slots = ();
foreach $align_id (0..$#aligns)
{
#	print "align: $align_id\n";
	foreach $w (keys %{$aligns[$align_id]})
	{
		$w_data = \%{$aligns[$align_id]{$w}};
		$slot_id_start = int($w_data->{'start'} / $time_slot_length);
		$slot_id_end = int(($w_data->{'start'} + $w_data->{'dur'}) / $time_slot_length);
#		print "$w, $w_data->{'p'}, $w_data->{'start'}, $w_data->{'dur'}, $slot_id_start, $slot_id_end\n";
		
		for ($slot_id = $slot_id_start; $slot_id <= $slot_id_end; $slot_id++)
		{
#			print "adding $w to $slot_id\n";
			if (exists($time_slots[$slot_id]{$w})) 
			{
#				print "$w ALREADY EXISTS IN THE SLOT $slot_id\n";
				$p1 = $time_slots[$slot_id]{$w}{'p'};
				$p2 = $w_data->{'p'};
				if ($p2 > $p1) {
					$time_slots[$slot_id]{$w}{'p'} = $p2;
					$time_slots[$slot_id]{$w}{'start'} = $w_data->{'start'};
					$time_slots[$slot_id]{$w}{'dur'} = $w_data->{'dur'};
				}
			}
			else
			{
				$time_slots[$slot_id]{$w}{'p'} = $w_data->{'p'};
				$time_slots[$slot_id]{$w}{'start'} = $w_data->{'start'};
				$time_slots[$slot_id]{$w}{'dur'} = $w_data->{'dur'};
			}
		}
	}
}

foreach $slot_id (0..$#time_slots)
{
#	print "slot: $slot_id\n";
	foreach $w (keys %{$time_slots[$slot_id]})
	{
		if ($w ne "*DELETE*")
		{
			$w_data = \%{$time_slots[$slot_id]{$w}};
			print "$slot_id|$w|$w_data->{'p'}|$w_data->{'start'}|$w_data->{'dur'}\n";
		}
	}
}

