#!/bin/bash

if [ $# -ne 2 ]; then
	echo "Usage: $0 lecture_lattices.list out_dir"
	exit
fi

lattices_list=$1
out_dir=$2

acscale=1
lmscale=30
wdpenalty=-25
posterior_scale=100

lecture_name=`basename $lattices_list .latlist`

mesh_dir=$out_dir/mesh
mkdir -p $mesh_dir

binseq_out=$out_dir/$lecture_name.binseq
echo -n "" > $binseq_out

for lat in `cat $lattices_list`; do
	echo $lat;

	mesh=$mesh_dir/`basename $lat`.mesh

	/usr/local/share/Srilm/bin/lattice-tool \
		-in-lattice $lat \
		-write-mesh $mesh \
		-read-htk \
		-htk-logbase 2.718281828459046 \
		-htk-acscale $acscale \
		-htk-lmscale $lmscale \
		-htk-wdpenalty $wdpenalty \
		-acoustic-mesh \
		-posterior-scale $posterior_scale \
	>> $out_dir/lattice-tool-mesh.log 2>&1

	./mesh2binseq.pl 2 _ 0.5 $mesh >> $binseq_out

#	rm $mesh
done
